# Coordinate transformation between different Frames. 

# This example illustrates the camera and world coordinate systems
# relationship. The position of the camera in the world coordinate
# system is printed from Camera::position(). Symetrically, the
# position of the world origin is given in the camera coordinate
# system by camera.cameraCoordinatesOf(0,0,0).

# Three sets of lines (red, green, blue) are drawned. They have different starting points, but
# common end points, located on a circle in the XY plane.

# All the red lines start from the camera position, and will hence always be aligned with the
# viewing direction, making them invisible.

# The green lines starting points' positions are determined from the camera coordinate system, using
# camera.worldCoordinatesOf(). As a result, these points will seem to be fixed in the screen,
# even when the camera is moved

# Finally, the blue lines are classically defined in the world coordinate system, and will move with
# the camera.

# Beautiful Moire pattern can be obtained with a proper rotation.

TEMPLATE = app
TARGET   = frameTransform
CONFIG  *= qt opengl warn_on release thread

HEADERS  = frameTransform.h
SOURCES  = frameTransform.cpp main.cpp


# Try to automatically set INCLUDEPATH and LIBS

# Test the default installation directories first:
unix {
  DEFAULT_HEADER_DIR = /usr/include/QGLViewer
  DEFAULT_LIB_DIR    = /usr/lib
}

macx {
  DEFAULT_HEADER_DIR = /usr/local/include/QGLViewer
  DEFAULT_LIB_DIR    = /usr/local/lib
}

win32 {
  DEFAULT_HEADER_DIR = C:\code\include\QGLViewer
  DEFAULT_LIB_DIR    = C:\code\lib\QGLViewer.lib
}

isEmpty( HEADER_DIR ) {
  exists( $$DEFAULT_HEADER_DIR/*.h ) {
    HEADER_DIR = $$DEFAULT_HEADER_DIR
  }
}

isEmpty( LIB_DIR ) {
  exists( $$DEFAULT_LIB_DIR/*QGLViewer* ) {
    LIB_DIR = $$DEFAULT_LIB_DIR
  }
}

# If it failed, check if this example is not part of the source package.
# In that case, QGLViewer should be in ../../src.
isEmpty( HEADER_DIR ) {
  exists( ../../src/*.h ) {
    HEADER_DIR = ../../src
  }
}

isEmpty( LIB_DIR ) {
  exists( ../../src/*QGLViewer* ) {
    LIB_DIR = ../../src
  }
}

win32 {
  isEmpty( LIB_DIR ) {
    exists( ..\..\src\Release\QGLViewer.lib ) {
      LIB_DIR = ..\..\src\Release
    }
  }
  isEmpty( LIB_DIR ) {
    exists( ..\..\src\Debug\QGLViewer.lib ) {
      LIB_DIR = ..\..\src\Debug
    }
  }
}

# We were unable to find directories...
isEmpty( HEADER_DIR ) : error( Unable to find header dir. Run qmake HEADER_DIR=... )
isEmpty( LIB_DIR ) :    error( Unable to find lib dir. Run qmake LIB_DIR=... )

# or we did it !
INCLUDEPATH *= $$HEADER_DIR
DEPENDPATH  *= $$HEADER_DIR
unix:  LIBS *= -L$$LIB_DIR -lQGLViewer
win32: LIBS *= $$LIB_DIR\QGLViewer.lib
macx:  LIBS *= -lobjc
