# Adding a graphical user interface around a QGLViewer.

# The same example as simpleViewer with an interface designed with designer. The interface.ui file
# is the description of the interface resulting of designer. The interface.cw file is the
# description of the signals and slots available. Here we use three slots and three signals to
# connect to and from the interface and the viewer.

# The designer cw files (custom widget), describing all the available
# signals and slots of the <code>libQGLViewer</code> classes are available in the

TEMPLATE = app
TARGET   = interface
CONFIG  += qt opengl warn_on release thread

HEADERS  = viewer.h 
SOURCES  = viewer.cpp main.cpp

INTERFACES = interface.ui

# Try to automatically set INCLUDEPATH and LIBS

# Test the default installation directories first:
unix {
  DEFAULT_HEADER_DIR = /usr/include/QGLViewer
  DEFAULT_LIB_DIR    = /usr/lib
}

macx {
  DEFAULT_HEADER_DIR = /usr/local/include/QGLViewer
  DEFAULT_LIB_DIR    = /usr/local/lib
}

win32 {
  DEFAULT_HEADER_DIR = C:\code\include\QGLViewer
  DEFAULT_LIB_DIR    = C:\code\lib\QGLViewer.lib
}

isEmpty( HEADER_DIR ) {
  exists( $$DEFAULT_HEADER_DIR/*.h ) {
    HEADER_DIR = $$DEFAULT_HEADER_DIR
  }
}

isEmpty( LIB_DIR ) {
  exists( $$DEFAULT_LIB_DIR/*QGLViewer* ) {
    LIB_DIR = $$DEFAULT_LIB_DIR
  }
}

# If it failed, check if this example is not part of the source package.
# In that case, QGLViewer should be in ../../src.
isEmpty( HEADER_DIR ) {
  exists( ../../src/*.h ) {
    HEADER_DIR = ../../src
  }
}

isEmpty( LIB_DIR ) {
  exists( ../../src/*QGLViewer* ) {
    LIB_DIR = ../../src
  }
}

win32 {
  isEmpty( LIB_DIR ) {
    exists( ..\..\src\Release\QGLViewer.lib ) {
      LIB_DIR = ..\..\src\Release
    }
  }
  isEmpty( LIB_DIR ) {
    exists( ..\..\src\Debug\QGLViewer.lib ) {
      LIB_DIR = ..\..\src\Debug
    }
  }
}

# We were unable to find directories...
isEmpty( HEADER_DIR ) : error( Unable to find header dir. Run qmake HEADER_DIR=... )
isEmpty( LIB_DIR ) :    error( Unable to find lib dir. Run qmake LIB_DIR=... )

# or we did it !
INCLUDEPATH *= $$HEADER_DIR
DEPENDPATH  *= $$HEADER_DIR
unix:  LIBS *= -L$$LIB_DIR -lQGLViewer
win32: LIBS *= $$LIB_DIR\QGLViewer.lib
macx:  LIBS *= -lobjc
