#include "keyFrames.h"

using namespace qglviewer;
using namespace std;

Viewer::Viewer()
  : nbKeyFrames(4)
{
  kfi_.setFrame(new Frame());
  kfi_.setLoopInterpolation();

  keyFrame_ = new ManipulatedFrame*[nbKeyFrames];
  
  // Create a random path
  for (int i=0; i<nbKeyFrames; i++)
    {
      keyFrame_[i] = new ManipulatedFrame();
      keyFrame_[i]->setPosition(-1.0 + 2.0*i/(nbKeyFrames-1), 0.0, 0.0);
      kfi_.addKeyFrame(keyFrame_[i]);
    }

  kfi_.startInterpolation();

  currentKF_ = 0;
  setManipulatedFrame(keyFrame_[currentKF_]);

  setMouseStateKey(QGLViewer::FRAME, Qt::NoButton);
  setMouseStateKey(QGLViewer::CAMERA, Qt::AltButton);

  help();
}


void Viewer::help()
{
  cout << endl << "\t\t- -  K e y F r a m e s  - -" << endl << endl;
  cout << "A frame is animated using a KeyFrameInterpolator" << endl;
  cout << "Use the left and right arrows to change the manipulated frame." << endl;
  cout << "+/- changes the interpolation speed." << endl;
  cout << "Return start-stops the interpolation." << endl;
  cout << "Press the Alt key to move the camera." << endl << endl;
}


void Viewer::keyPressEvent(QKeyEvent *e)
{
  switch (e->key())
    {
    case Qt::Key_Left :
      currentKF_ = (currentKF_+nbKeyFrames-1) % nbKeyFrames;
      setManipulatedFrame(keyFrame_[currentKF_]);
      updateGL();
      break;
    case Qt::Key_Right :
      currentKF_ = (currentKF_+1) % nbKeyFrames;
      setManipulatedFrame(keyFrame_[currentKF_]);
      updateGL();
      break;
    case Qt::Key_Return :
      kfi_.toggleInterpolation();
      break;
    case Qt::Key_Plus :
      kfi_.setInterpolationSpeed(kfi_.interpolationSpeed()+0.25);
      break;
    case Qt::Key_Minus :
      kfi_.setInterpolationSpeed(kfi_.interpolationSpeed()-0.25);
      break;
    // case Qt::Key_C :
      // kfi_.setClosedPath(!kfi_.closedPath());
      // break;
    default:
      QGLViewer::keyPressEvent(e);
    }
}

void Viewer::draw()
{
  glPushMatrix();
  glMultMatrixd(kfi_.frame()->matrix());
  drawAxis(0.3);
  glPopMatrix();
    
  kfi_.drawPath(5, 15);

  for (int i=0; i<nbKeyFrames; i++)
    {
      glPushMatrix();
      Frame frame;
      frame.setPosition(kfi_.keyFramePosition(i));
      frame.setOrientation(kfi_.keyFrameOrientation(i));
      glMultMatrixd(frame.matrix());
      if (i == currentKF_)
	drawAxis(0.5);
      else
	drawAxis(0.3);
      glPopMatrix();
    }
}

