# A more complex exemple that combines manipulatedFrames, selection and constraints.

# This exemple illustrates different functions of the viewer. It displays a famous luxo lamp
# (Pixar) that can be interactively manipulated with the mouse. It illustrates the use of several
# ManipulatedFrames in the same scene.

# Shift click on any part of the lamp to select it, and then move it with the mouse. To move the
# camera select the background or press the Alt key (default modifier keys are switched).

# A simpler object selection example is given in <a href="select.html"><code>select</code></a>.<br/>
# A simpler frame displacement example is given in <a href="manipulatedFrame.html"><code>manipulatedFrame</code></a>.<br/>
# A simpler constrained frame example is given in <a href="constrainedFrame.html"><code>constrainedFrame</code></a>.<br/>

TEMPLATE = app
TARGET   = luxo
CONFIG  += qt opengl warn_on release thread

HEADERS  = luxo.h
SOURCES  = luxo.cpp main.cpp

# Try to automatically set INCLUDEPATH and LIBS

# Test the default installation directories first:
unix {
  DEFAULT_HEADER_DIR = /usr/include/QGLViewer
  DEFAULT_LIB_DIR    = /usr/lib
}

macx {
  DEFAULT_HEADER_DIR = /usr/local/include/QGLViewer
  DEFAULT_LIB_DIR    = /usr/local/lib
}

win32 {
  DEFAULT_HEADER_DIR = C:\code\include\QGLViewer
  DEFAULT_LIB_DIR    = C:\code\lib\QGLViewer.lib
}

isEmpty( HEADER_DIR ) {
  exists( $$DEFAULT_HEADER_DIR/*.h ) {
    HEADER_DIR = $$DEFAULT_HEADER_DIR
  }
}

isEmpty( LIB_DIR ) {
  exists( $$DEFAULT_LIB_DIR/*QGLViewer* ) {
    LIB_DIR = $$DEFAULT_LIB_DIR
  }
}

# If it failed, check if this example is not part of the source package.
# In that case, QGLViewer should be in ../../src.
isEmpty( HEADER_DIR ) {
  exists( ../../src/*.h ) {
    HEADER_DIR = ../../src
  }
}

isEmpty( LIB_DIR ) {
  exists( ../../src/*QGLViewer* ) {
    LIB_DIR = ../../src
  }
}

win32 {
  isEmpty( LIB_DIR ) {
    exists( ..\..\src\Release\QGLViewer.lib ) {
      LIB_DIR = ..\..\src\Release
    }
  }
  isEmpty( LIB_DIR ) {
    exists( ..\..\src\Debug\QGLViewer.lib ) {
      LIB_DIR = ..\..\src\Debug
    }
  }
}

# We were unable to find directories...
isEmpty( HEADER_DIR ) : error( Unable to find header dir. Run qmake HEADER_DIR=... )
isEmpty( LIB_DIR ) :    error( Unable to find lib dir. Run qmake LIB_DIR=... )

# or we did it !
INCLUDEPATH *= $$HEADER_DIR
DEPENDPATH  *= $$HEADER_DIR
unix:  LIBS *= -L$$LIB_DIR -lQGLViewer
win32: LIBS *= $$LIB_DIR\QGLViewer.lib
macx:  LIBS *= -lobjc
