# A <code>ManipulatedFrame</code> can be moved with the mouse in the scene.

# This example illustrates the mouse driven displacement of a frame in
# the scene. The frame is moved by pressing the Alt key while using the
# mouse (the key can be changed through the constant FRAME_MOUSE_MOVE_STATE_KEY).

# The frame is drawned at its position using a glMultMatrix of the frame associated
# matrix. This matrix will be changed when the mouse moves, thus changing the position
# of the frame.

# We use a glPushMatrix and glPopMatrix to save and restore the model view
# matrix. It is not needed here as nothing is drawn after the frame, but it
# is a good habbit for the general cases.

TEMPLATE = app
TARGET   = manipulatedFrame
CONFIG  += qt opengl warn_on release thread

HEADERS  = manipulatedFrame.h
SOURCES  = manipulatedFrame.cpp main.cpp

# Try to automatically set INCLUDEPATH and LIBS

# Test the default installation directories first:
unix {
  DEFAULT_HEADER_DIR = /usr/include/QGLViewer
  DEFAULT_LIB_DIR    = /usr/lib
}

macx {
  DEFAULT_HEADER_DIR = /usr/local/include/QGLViewer
  DEFAULT_LIB_DIR    = /usr/local/lib
}

win32 {
  DEFAULT_HEADER_DIR = C:\code\include\QGLViewer
  DEFAULT_LIB_DIR    = C:\code\lib\QGLViewer.lib
}

isEmpty( HEADER_DIR ) {
  exists( $$DEFAULT_HEADER_DIR/*.h ) {
    HEADER_DIR = $$DEFAULT_HEADER_DIR
  }
}

isEmpty( LIB_DIR ) {
  exists( $$DEFAULT_LIB_DIR/*QGLViewer* ) {
    LIB_DIR = $$DEFAULT_LIB_DIR
  }
}

# If it failed, check if this example is not part of the source package.
# In that case, QGLViewer should be in ../../src.
isEmpty( HEADER_DIR ) {
  exists( ../../src/*.h ) {
    HEADER_DIR = ../../src
  }
}

isEmpty( LIB_DIR ) {
  exists( ../../src/*QGLViewer* ) {
    LIB_DIR = ../../src
  }
}

win32 {
  isEmpty( LIB_DIR ) {
    exists( ..\..\src\Release\QGLViewer.lib ) {
      LIB_DIR = ..\..\src\Release
    }
  }
  isEmpty( LIB_DIR ) {
    exists( ..\..\src\Debug\QGLViewer.lib ) {
      LIB_DIR = ..\..\src\Debug
    }
  }
}

# We were unable to find directories...
isEmpty( HEADER_DIR ) : error( Unable to find header dir. Run qmake HEADER_DIR=... )
isEmpty( LIB_DIR ) :    error( Unable to find lib dir. Run qmake LIB_DIR=... )

# or we did it !
INCLUDEPATH *= $$HEADER_DIR
DEPENDPATH  *= $$HEADER_DIR
unix:  LIBS *= -L$$LIB_DIR -lQGLViewer
win32: LIBS *= $$LIB_DIR\QGLViewer.lib
macx:  LIBS *= -lobjc
