#include "stereoViewer.h"
#include <qapplication.h>
#include <math.h>

using namespace std;

// Constructor must call the base class constructor.
// See the QT man page for details on QGLFormat.
Viewer::Viewer(const QGLFormat& format)
  : QGLViewer(format)
{
  // Activate the stereo display. Press 's' to toggle.
  setStereoDisplay(true);

  help();
}

void Viewer::help()
{
  cout << endl << "\t\t- -  S t e r e o V i e w e r  - -" << endl << endl;
  cout << "The display of your application with 3D stereo vision does not require" << endl;
  cout << "any change in your code. The draw() function is unchanged." << endl << endl;
  cout << "If you get a \"Stereo not supported on this display\" error message, check that" << endl;
  cout << "your machine supports stereo (search for quad-buffer in glxinfo and find stereo glasses!)" << endl;
  cout << "Send an e-mail if you were able to run other stereo applications." << endl << endl;
  cout << "Press 'S' to toggle the stereo display." << endl << endl;
}

void Viewer::draw()
{
  // Draws a spiral
  const float nbSteps = 500.0;
  glBegin(GL_QUAD_STRIP);
  for (float i=0; i<nbSteps; ++i)
    {
      float ratio = i/nbSteps;
      float angle = 20.0*ratio;
      float c = cos(angle);
      float s = sin(angle);
      float r1 = 1.0 - 0.8*ratio;
      float r2 = 0.8 - 0.8*ratio;
      float alt = ratio - 0.5;
      const float nor = .5;
      const float up = sqrt(1.0-nor*nor);
      glColor3f(1-ratio, .2 , ratio);
      glNormal3f(nor*c, up, nor*s);
      glVertex3f(r1*c, alt, r1*s);
      glVertex3f(r2*c, alt+0.05, r2*s);
    }
  glEnd();

  return;
}
